@@ -559,10 +559,21 @@ def instantiate_extension(
     return extension_instance
 
 
+g_entry_points_impl = None
+
+
 def get_extensions(logger):
+    global g_entry_points_impl
     group_name = 'launch_ros.node_action'
+    if g_entry_points_impl is None:
+        g_entry_points_impl = importlib_metadata.entry_points()
+    entry_points_impl = g_entry_points_impl
+    if hasattr(entry_points_impl, 'select'):
+        groups = entry_points_impl.select(group=group_name)
+    else:
+        groups = entry_points_impl.get(group_name, [])
     entry_points = {}
-    for entry_point in importlib_metadata.entry_points().get(group_name, []):
+    for entry_point in groups:
         entry_points[entry_point.name] = entry_point
     extension_types = {}
     for entry_point in entry_points:
